@@ -17,6 +17,7 @@
 package net.lingala.zip4j.headers;
 
 import net.lingala.zip4j.exception.ZipException;
+import net.lingala.zip4j.io.inputstream.NumberedSplitRandomAccessFile;
 import net.lingala.zip4j.model.AESExtraDataRecord;
 import net.lingala.zip4j.model.CentralDirectory;
 import net.lingala.zip4j.model.DataDescriptor;
@@ -47,6 +48,7 @@ import java.util.List;
 import static net.lingala.zip4j.headers.HeaderUtil.decodeStringWithCharset;
 import static net.lingala.zip4j.util.BitUtils.isBitSet;
 import static net.lingala.zip4j.util.InternalZipConstants.ENDHDR;
+import static net.lingala.zip4j.util.InternalZipConstants.ZIP_64_NUMBER_OF_ENTRIES_LIMIT;
 import static net.lingala.zip4j.util.InternalZipConstants.ZIP_64_SIZE_LIMIT;
 import static net.lingala.zip4j.util.Zip4jUtil.readFully;
 
@@ -76,6 +78,10 @@ public class HeaderReader {
       throw new ZipException("Zip headers not found. Probably not a zip file or a corrupted zip file", e);
     }
 
+    if (zipModel.getEndOfCentralDirectoryRecord().getTotalNumberOfEntriesInCentralDirectory() == 0) {
+      return zipModel;
+    }
+
     // If file is Zip64 format, Zip64 headers have to be read before reading central directory
     zipModel.setZip64EndOfCentralDirectoryLocator(readZip64EndOfCentralDirectoryLocator(zip4jRaf, rawIO));
 
@@ -96,17 +102,18 @@ public class HeaderReader {
 
   private EndOfCentralDirectoryRecord readEndOfCentralDirectoryRecord(RandomAccessFile zip4jRaf, RawIO rawIO, Charset charset)
       throws IOException {
-    long pos = zip4jRaf.length() - ENDHDR;
+    long zipFileLengthWithoutEndHeader = zip4jRaf.length() - ENDHDR;
+    long pos = zipFileLengthWithoutEndHeader;
 
     EndOfCentralDirectoryRecord endOfCentralDirectoryRecord = new EndOfCentralDirectoryRecord();
 
     int counter = 0;
     int headerSignature;
     do {
-      zip4jRaf.seek(pos--);
+      seekInCurrentPart(zip4jRaf, pos--);
       counter++;
     } while (((headerSignature = rawIO.readIntLittleEndian(zip4jRaf))
-        != HeaderSignature.END_OF_CENTRAL_DIRECTORY.getValue()) && counter <= 3000);
+        != HeaderSignature.END_OF_CENTRAL_DIRECTORY.getValue()) && counter <= zipFileLengthWithoutEndHeader);
 
     if (headerSignature != HeaderSignature.END_OF_CENTRAL_DIRECTORY.getValue()) {
       throw new ZipException("Zip headers not found. Probably not a zip file");
@@ -421,7 +428,8 @@ public class HeaderReader {
     }
 
     Zip64ExtendedInfo zip64ExtendedInfo = readZip64ExtendedInfo(fileHeader.getExtraDataRecords(), rawIO,
-        fileHeader.getUncompressedSize(), fileHeader.getCompressedSize(), fileHeader.getOffsetLocalHeader());
+        fileHeader.getUncompressedSize(), fileHeader.getCompressedSize(), fileHeader.getOffsetLocalHeader(),
+        fileHeader.getDiskNumberStart());
 
     if (zip64ExtendedInfo == null) {
       return;
@@ -456,7 +464,7 @@ public class HeaderReader {
     }
 
     Zip64ExtendedInfo zip64ExtendedInfo = readZip64ExtendedInfo(localFileHeader.getExtraDataRecords(), rawIO,
-        localFileHeader.getUncompressedSize(), localFileHeader.getCompressedSize(), 0);
+        localFileHeader.getUncompressedSize(), localFileHeader.getCompressedSize(), 0, 0);
 
     if (zip64ExtendedInfo == null) {
       return;
@@ -474,8 +482,8 @@ public class HeaderReader {
   }
 
   private Zip64ExtendedInfo readZip64ExtendedInfo(List<ExtraDataRecord> extraDataRecords, RawIO rawIO,
-                                                  long uncompressedSize, long compressedSize, long offsetLocalHeader)
-      throws ZipException {
+                                                  long uncompressedSize, long compressedSize, long offsetLocalHeader,
+                                                  int diskNumberStart) {
 
     for (ExtraDataRecord extraDataRecord : extraDataRecords) {
       if (extraDataRecord == null) {
@@ -488,7 +496,7 @@ public class HeaderReader {
         byte[] extraData = extraDataRecord.getData();
 
         if (extraDataRecord.getSizeOfData() <= 0) {
-          throw new ZipException("No data present for Zip64Extended info");
+          return null;
         }
 
         int counter = 0;
@@ -497,7 +505,7 @@ public class HeaderReader {
           counter += 8;
         }
 
-        if ( counter < extraDataRecord.getSizeOfData() && compressedSize == ZIP_64_SIZE_LIMIT) {
+        if (counter < extraDataRecord.getSizeOfData() && compressedSize == ZIP_64_SIZE_LIMIT) {
           zip64ExtendedInfo.setCompressedSize(rawIO.readLongLittleEndian(extraData, counter));
           counter += 8;
         }
@@ -507,7 +515,7 @@ public class HeaderReader {
           counter += 8;
         }
 
-        if (counter < extraDataRecord.getSizeOfData()) {
+        if (counter < extraDataRecord.getSizeOfData() && diskNumberStart == ZIP_64_NUMBER_OF_ENTRIES_LIMIT) {
           zip64ExtendedInfo.setDiskNumberStart(rawIO.readIntLittleEndian(extraData, counter));
         }
 
@@ -521,7 +529,7 @@ public class HeaderReader {
     long pos = zip4jRaf.length() - ENDHDR;
 
     do {
-      zip4jRaf.seek(pos--);
+      seekInCurrentPart(zip4jRaf, pos--);
     } while (rawIO.readIntLittleEndian(zip4jRaf) != HeaderSignature.END_OF_CENTRAL_DIRECTORY.getValue());
 
     // Now the file pointer is at the end of signature of Central Dir Rec
@@ -532,7 +540,7 @@ public class HeaderReader {
     // 4 -> number of the disk with the start of the zip64 end of central directory
     // 4 -> zip64 end of central dir locator signature
     // Refer to Appnote for more information
-    zip4jRaf.seek(zip4jRaf.getFilePointer() - 4 - 4 - 8 - 4 - 4);
+    seekInCurrentPart(zip4jRaf, zip4jRaf.getFilePointer() - 4 - 4 - 8 - 4 - 4);
   }
 
   public LocalFileHeader readLocalFileHeader(InputStream inputStream, Charset charset) throws IOException {
@@ -723,4 +731,12 @@ public class HeaderReader {
 
     return zipModel.getEndOfCentralDirectoryRecord().getTotalNumberOfEntriesInCentralDirectory();
   }
+
+  private void seekInCurrentPart(RandomAccessFile randomAccessFile, long pos) throws IOException {
+    if (randomAccessFile instanceof NumberedSplitRandomAccessFile) {
+      ((NumberedSplitRandomAccessFile) randomAccessFile).seekInCurrentPart(pos);
+    } else {
+      randomAccessFile.seek(pos);
+    }
+  }
 }
