@@ -79,6 +79,26 @@ public class HeaderUtil {
     }
   }
 
+
+  public static long getOffsetOfNextEntry(ZipModel zipModel, FileHeader fileHeader) throws ZipException {
+    int indexOfFileHeader = getIndexOfFileHeader(zipModel, fileHeader);
+
+    List<FileHeader> fileHeaders = zipModel.getCentralDirectory().getFileHeaders();
+    if (indexOfFileHeader == fileHeaders.size() - 1) {
+      return getOffsetOfEndOfCentralDirectory(zipModel);
+    } else {
+      return fileHeaders.get(indexOfFileHeader + 1).getOffsetLocalHeader();
+    }
+  }
+
+  private static long getOffsetOfEndOfCentralDirectory(ZipModel zipModel) {
+    if (zipModel.isZip64Format()) {
+      return zipModel.getZip64EndOfCentralDirectoryRecord().getOffsetStartCentralDirectoryWRTStartDiskNumber();
+    }
+
+    return zipModel.getEndOfCentralDirectoryRecord().getOffsetOfStartOfCentralDirectory();
+  }
+
   private static FileHeader getFileHeaderWithExactMatch(ZipModel zipModel, String fileName) throws ZipException {
     if (zipModel == null) {
       throw new ZipException("zip model is null, cannot determine file header with exact match for fileName: "
