@@ -2,6 +2,7 @@ package net.lingala.zip4j.util;
 
 import net.lingala.zip4j.exception.ZipException;
 import net.lingala.zip4j.model.ZipModel;
+import net.lingala.zip4j.model.ZipParameters;
 import net.lingala.zip4j.progress.ProgressMonitor;
 
 import java.io.File;
@@ -16,6 +17,7 @@ import java.nio.file.attribute.FileTime;
 import java.nio.file.attribute.PosixFileAttributeView;
 import java.nio.file.attribute.PosixFilePermission;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -120,6 +122,15 @@ public class FileUtils {
     return result;
   }
 
+  public static String getFileNameWithoutExtension(String fileName) {
+    int pos = fileName.lastIndexOf(".");
+    if (pos == -1) {
+      return fileName;
+    }
+
+    return fileName.substring(0, pos);
+  }
+
   public static String getZipFileNameWithoutExtension(String zipFile) throws ZipException {
     if (!isStringNotNullAndNotEmpty(zipFile)) {
       throw new ZipException("zip file name is empty or null, cannot determine zip file name");
@@ -181,21 +192,28 @@ public class FileUtils {
     return splitZipFiles;
   }
 
-  public static String getRelativeFileName(String file, String rootFolderPath, String rootFolderNameInZip)
-      throws ZipException {
+  public static String getRelativeFileName(File fileToAdd, ZipParameters zipParameters) throws ZipException {
 
     String fileName;
     try {
-      String fileCanonicalPath = new File(file).getCanonicalPath();
-      if (isStringNotNullAndNotEmpty(rootFolderPath)) {
-        File rootFolderFile = new File(rootFolderPath);
+      String fileCanonicalPath = fileToAdd.getCanonicalPath();
+      if (isStringNotNullAndNotEmpty(zipParameters.getDefaultFolderPath())) {
+        File rootFolderFile = new File(zipParameters.getDefaultFolderPath());
         String rootFolderFileRef = rootFolderFile.getCanonicalPath();
 
         if (!rootFolderFileRef.endsWith(FILE_SEPARATOR)) {
           rootFolderFileRef += FILE_SEPARATOR;
         }
 
-        String tmpFileName = fileCanonicalPath.substring(rootFolderFileRef.length());
+        String tmpFileName;
+
+        if (isSymbolicLink(fileToAdd)) {
+          String rootPath = new File(fileToAdd.getParentFile().getCanonicalFile().getPath() + File.separator + fileToAdd.getCanonicalFile().getName()).getPath();
+          tmpFileName = rootPath.substring(rootFolderFileRef.length());
+        } else {
+           tmpFileName = fileCanonicalPath.substring(rootFolderFileRef.length());
+        }
+
         if (tmpFileName.startsWith(System.getProperty("file.separator"))) {
           tmpFileName = tmpFileName.substring(1);
         }
@@ -208,34 +226,46 @@ public class FileUtils {
         } else {
           String bkFileName = tmpFileName.substring(0, tmpFileName.lastIndexOf(tmpFile.getName()));
           bkFileName = bkFileName.replaceAll("\\\\", "/");
-          tmpFileName = bkFileName + tmpFile.getName();
+          tmpFileName = bkFileName + getNameOfFileInZip(tmpFile, zipParameters.getFileNameInZip());
         }
 
         fileName = tmpFileName;
       } else {
         File relFile = new File(fileCanonicalPath);
+        fileName = getNameOfFileInZip(relFile, zipParameters.getFileNameInZip());
         if (relFile.isDirectory()) {
-          fileName = relFile.getName() + ZIP_FILE_SEPARATOR;
-        } else {
-          fileName = relFile.getName();
+          fileName += ZIP_FILE_SEPARATOR;
         }
       }
     } catch (IOException e) {
       throw new ZipException(e);
     }
 
+    String rootFolderNameInZip = zipParameters.getRootFolderNameInZip();
     if (Zip4jUtil.isStringNotNullAndNotEmpty(rootFolderNameInZip)) {
       if (!rootFolderNameInZip.endsWith("\\") && !rootFolderNameInZip.endsWith("/")) {
         rootFolderNameInZip = rootFolderNameInZip + InternalZipConstants.FILE_SEPARATOR;
       }
 
-      rootFolderNameInZip = rootFolderNameInZip.replaceAll("\\\\", "/");
+      rootFolderNameInZip = rootFolderNameInZip.replaceAll("\\\\", ZIP_FILE_SEPARATOR);
       fileName = rootFolderNameInZip + fileName;
     }
 
     return fileName;
   }
 
+  private static String getNameOfFileInZip(File fileToAdd, String fileNameInZip) throws IOException {
+    if (isStringNotNullAndNotEmpty(fileNameInZip)) {
+      return fileNameInZip;
+    }
+
+    if (isSymbolicLink(fileToAdd)) {
+      return fileToAdd.toPath().toRealPath().getFileName().toString();
+    }
+
+    return fileToAdd.getName();
+  }
+
   public static boolean isZipEntryDirectory(String fileNameInZip) {
     return fileNameInZip.endsWith("/") || fileNameInZip.endsWith("\\");
   }
@@ -296,6 +326,61 @@ public class FileUtils {
     }
   }
 
+  public static boolean isNumberedSplitFile(File file) {
+    return file.getName().endsWith(InternalZipConstants.SEVEN_ZIP_SPLIT_FILE_EXTENSION_PATTERN);
+  }
+
+  public static String getFileExtension(File file) {
+    String fileName = file.getName();
+
+    if (!fileName.contains(".")) {
+      return "";
+    }
+
+    return fileName.substring(fileName.lastIndexOf(".") + 1);
+  }
+
+  /**
+   * A helper method to retrieve all split files which are of the format split by 7-zip, i.e, .zip.001, .zip.002, etc.
+   * This method also sorts all the files by their split part
+   * @param firstNumberedFile - first split file
+   * @return sorted list of split files. Returns an empty list if no files of that pattern are found in the current directory
+   */
+  public static File[] getAllSortedNumberedSplitFiles(File firstNumberedFile) {
+    String zipFileNameWithoutExtension = FileUtils.getFileNameWithoutExtension(firstNumberedFile.getName());
+    File[] allSplitFiles = firstNumberedFile.getParentFile().listFiles((dir, name) -> name.startsWith(zipFileNameWithoutExtension + "."));
+
+    if(allSplitFiles == null) {
+      return new File[0];
+    }
+
+    Arrays.sort(allSplitFiles);
+
+    return allSplitFiles;
+  }
+
+  public static String getNextNumberedSplitFileCounterAsExtension(int index) {
+    return "." + getExtensionZerosPrefix(index) + (index + 1);
+  }
+
+  public static boolean isSymbolicLink(File file) {
+    try {
+      return Files.isSymbolicLink(file.toPath());
+    } catch (Exception | Error e) {
+      return false;
+    }
+  }
+
+  private static String getExtensionZerosPrefix(int index) {
+    if (index < 9) {
+      return "00";
+    } else if (index < 99) {
+      return "0";
+    } else {
+      return "";
+    }
+  }
+
   private static void applyWindowsFileAttributes(Path file, byte[] fileAttributes) {
     if (fileAttributes[0] == 0) {
       // No file attributes defined in the archive
@@ -366,6 +451,7 @@ public class FileUtils {
 
       fileAttributes[3] = setBitIfApplicable(Files.isRegularFile(file), fileAttributes[3], 7);
       fileAttributes[3] = setBitIfApplicable(Files.isDirectory(file), fileAttributes[3], 6);
+      fileAttributes[3] = setBitIfApplicable(Files.isSymbolicLink(file), fileAttributes[3], 5);
       fileAttributes[3] = setBitIfApplicable(posixFilePermissions.contains(OWNER_READ), fileAttributes[3], 0);
       fileAttributes[2] = setBitIfApplicable(posixFilePermissions.contains(OWNER_WRITE), fileAttributes[2], 7);
       fileAttributes[2] = setBitIfApplicable(posixFilePermissions.contains(OWNER_EXECUTE), fileAttributes[2], 6);
