@@ -16,6 +16,7 @@
 
 package net.lingala.zip4j.util;
 
+import java.io.File;
 import java.nio.charset.Charset;
 
 public final class InternalZipConstants {
@@ -30,6 +31,7 @@ public final class InternalZipConstants {
   //AES Constants
   public static final int AES_AUTH_LENGTH = 10;
   public static final int AES_BLOCK_SIZE = 16;
+  public static final int AES_EXTRA_DATA_RECORD_SIZE = 11;
 
   public static final int MIN_SPLIT_LENGTH = 65536;
   public static final long ZIP_64_SIZE_LIMIT = 4294967295L;
@@ -48,11 +50,13 @@ public final class InternalZipConstants {
 
   public static final String ZIP_STANDARD_CHARSET = "Cp437";
 
-  public static final String FILE_SEPARATOR = System.getProperty("file.separator");
+  public static final String FILE_SEPARATOR = File.separator;
 
   public static final String ZIP_FILE_SEPARATOR = "/";
 
   public static final int MAX_ALLOWED_ZIP_COMMENT_LENGTH = 0xFFFF;
 
   public static final Charset CHARSET_UTF_8 = Charset.forName("UTF-8");
+
+  public static final String SEVEN_ZIP_SPLIT_FILE_EXTENSION_PATTERN = ".zip.001";
 }
