@@ -18,11 +18,14 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.file.Files;
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Optional;
 import java.util.Set;
 
+import static net.lingala.zip4j.testutils.TestUtils.getTestFileFromResources;
+import static net.lingala.zip4j.testutils.ZipFileVerifier.verifyZipFileByExtractingAllFiles;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.fail;
 
@@ -141,20 +144,20 @@ public class ExtractZipFileIT extends AbstractIT {
 
     File[] outputFiles = outputFolder.listFiles();
     assertThat(outputFiles).hasSize(1);
-    ZipFileVerifier.verifyFileContent(TestUtils.getTestFileFromResources("sample_text_large.txt"), outputFiles[0]);
+    ZipFileVerifier.verifyFileContent(getTestFileFromResources("sample_text_large.txt"), outputFiles[0]);
   }
 
   @Test
   public void testExtractFileWithFileHeaderWithAes128AndInDirectory() throws IOException {
     ZipParameters zipParameters = createZipParameters(EncryptionMethod.AES, AesKeyStrength.KEY_STRENGTH_128);
     ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
-    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+    zipFile.addFolder(getTestFileFromResources(""), zipParameters);
 
     FileHeader fileHeader = zipFile.getFileHeader("test-files/öüäöäö/asöäööl");
     zipFile.extractFile(fileHeader, outputFolder.getPath());
 
     File outputFile = getFileWithNameFrom(outputFolder, "asöäööl");
-    ZipFileVerifier.verifyFileContent(TestUtils.getTestFileFromResources("öüäöäö/asöäööl"), outputFile);
+    ZipFileVerifier.verifyFileContent(getTestFileFromResources("öüäöäö/asöäööl"), outputFile);
   }
 
   @Test
@@ -168,7 +171,7 @@ public class ExtractZipFileIT extends AbstractIT {
     zipFile.extractFile(fileHeader, outputFolder.getPath(), newFileName);
 
     File outputFile = getFileWithNameFrom(outputFolder, newFileName);
-    ZipFileVerifier.verifyFileContent(TestUtils.getTestFileFromResources("sample_text_large.txt"), outputFile);
+    ZipFileVerifier.verifyFileContent(getTestFileFromResources("sample_text_large.txt"), outputFile);
   }
 
   @Test
@@ -176,35 +179,40 @@ public class ExtractZipFileIT extends AbstractIT {
     ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
     zipFile.addFiles(FILES_TO_ADD);
 
-    expectedException.expect(ZipException.class);
-    expectedException.expectMessage("No file found with name NOT_EXISTING in zip file");
+    try {
+      zipFile.extractFile("NOT_EXISTING", outputFolder.getPath());
+      fail("Should throw an exception");
+    } catch (ZipException e) {
+      assertThat(e).isNotNull();
+      assertThat(e.getType()).isEqualTo(ZipException.Type.FILE_NOT_FOUND);
+      assertThat(e.getMessage()).isEqualTo("No file found with name NOT_EXISTING in zip file");
+    }
 
-    zipFile.extractFile("NOT_EXISTING", outputFolder.getPath());
   }
 
   @Test
   public void testExtractFileWithFileNameWithZipStandardEncryption() throws IOException {
     ZipParameters zipParameters = createZipParameters(EncryptionMethod.ZIP_STANDARD, null);
     ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
-    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+    zipFile.addFolder(getTestFileFromResources(""), zipParameters);
 
     zipFile.extractFile("test-files/sample_directory/favicon.ico", outputFolder.getPath());
 
     File outputFile = getFileWithNameFrom(outputFolder, "favicon.ico");
-    ZipFileVerifier.verifyFileContent(TestUtils.getTestFileFromResources("sample_directory/favicon.ico"), outputFile);
+    ZipFileVerifier.verifyFileContent(getTestFileFromResources("sample_directory/favicon.ico"), outputFile);
   }
 
   @Test
   public void testExtractFileWithFileNameWithZipStandardEncryptionAndNewFileName() throws IOException {
     ZipParameters zipParameters = createZipParameters(EncryptionMethod.ZIP_STANDARD, null);
     ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
-    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+    zipFile.addFolder(getTestFileFromResources(""), zipParameters);
 
     String newFileName = "newFileName";
     zipFile.extractFile("test-files/sample_directory/favicon.ico", outputFolder.getPath(), newFileName);
 
     File outputFile = getFileWithNameFrom(outputFolder, newFileName);
-    ZipFileVerifier.verifyFileContent(TestUtils.getTestFileFromResources("sample_directory/favicon.ico"), outputFile);
+    ZipFileVerifier.verifyFileContent(getTestFileFromResources("sample_directory/favicon.ico"), outputFile);
   }
 
   @Test
@@ -259,7 +267,7 @@ public class ExtractZipFileIT extends AbstractIT {
   @Test
   public void testExtractFilesForAZipMadeWithZip4jv1AndStoreCompressionWithAES() throws IOException {
     File zipArchiveToTest = getTestArchiveFromResources("store_compression_made_with_v1.3.3.zip");
-    ZipFileVerifier.verifyZipFileByExtractingAllFiles(zipArchiveToTest, "aaaaaaaa".toCharArray(), outputFolder, 5,
+    verifyZipFileByExtractingAllFiles(zipArchiveToTest, "aaaaaaaa".toCharArray(), outputFolder, 5,
         false);
   }
 
@@ -307,7 +315,7 @@ public class ExtractZipFileIT extends AbstractIT {
 
   @Test
   public void testExtractZipFileWithChineseCharsetGBK() throws IOException {
-    String expactedFileName = "fff - 副本.txt";
+    String expectedFileName = "fff - 副本.txt";
     ZipFile zipFile = new ZipFile(getTestArchiveFromResources("testfile_with_chinese_filename_by_7zip.zip"));
 
     zipFile.setCharset(CHARSET_GBK);
@@ -316,7 +324,7 @@ public class ExtractZipFileIT extends AbstractIT {
     assertThat(zipFile.getFileHeaders()).hasSize(2);
     Set<String> filenameSet = new HashSet<>();
     Files.walk(outputFolder.toPath()).forEach(file -> filenameSet.add(file.getFileName().toString()));
-    assertThat(filenameSet.contains(expactedFileName)).isTrue();
+    assertThat(filenameSet.contains(expectedFileName)).isTrue();
   }
 
   @Test
@@ -376,6 +384,38 @@ public class ExtractZipFileIT extends AbstractIT {
     zipFile.extractAll(temporaryFolder.toString());
   }
 
+  @Test
+  public void testExtractZipFileEmptyZipFileExtractsNone() throws IOException {
+    ZipFile zipFile = new ZipFile(getTestArchiveFromResources("valid_empty_zip_file.zip"));
+    zipFile.extractAll(outputFolder.getPath());
+    assertThat(outputFolder.listFiles()).isEmpty();
+  }
+  
+  @Test
+  public void testExtractZipFileCRCError() throws IOException {
+    ZipFile zipFile = new ZipFile(getTestArchiveFromResources("archive_with_invalid_zip64_headers.zip"));
+    zipFile.extractAll(outputFolder.getPath());
+    assertThat(outputFolder.listFiles()).contains(
+            new File(outputFolder, "index.html"),
+            new File(outputFolder, "images"));
+  }
+
+  @Test
+  public void testExtractZipFileOf7ZipFormatSplitWithoutEncryption() throws IOException {
+    List<File> filesToAddToZip = new ArrayList<>(FILES_TO_ADD);
+    filesToAddToZip.add(getTestFileFromResources("file_PDF_1MB.pdf"));
+    File firstSplitFile = createZipFileAndSplit(filesToAddToZip, 102400, false, null);
+    verifyZipFileByExtractingAllFiles(firstSplitFile, outputFolder, 4);
+  }
+
+  @Test
+  public void testExtractZipFileOf7ZipFormatSplitWithAESEncryption() throws IOException {
+    List<File> filesToAddToZip = new ArrayList<>(FILES_TO_ADD);
+    filesToAddToZip.add(getTestFileFromResources("file_PDF_1MB.pdf"));
+    File firstSplitFile = createZipFileAndSplit(filesToAddToZip, 102000, true, EncryptionMethod.AES);
+    verifyZipFileByExtractingAllFiles(firstSplitFile, PASSWORD, outputFolder, 4);
+  }
+
   private void testExtractNestedZipFileWithEncrpytion(EncryptionMethod innerZipEncryption,
                                                        EncryptionMethod outerZipEncryption) throws IOException {
     File innerZipFile = temporaryFolder.newFile("inner.zip");
@@ -439,4 +479,14 @@ public class ExtractZipFileIT extends AbstractIT {
     return file.get();
   }
 
+  private File createZipFileAndSplit(List<File> filesToAddToZip, long splitLength, boolean encrypt, EncryptionMethod encryptionMethod) throws IOException {
+    ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setEncryptFiles(encrypt);
+    zipParameters.setEncryptionMethod(encryptionMethod);
+    zipFile.addFiles(filesToAddToZip, zipParameters);
+
+    return TestUtils.splitFileWith7ZipFormat(zipFile.getFile(), temporaryFolder.getRoot(), splitLength);
+  }
+
 }
