@@ -188,6 +188,16 @@ public class FileHeaderFactoryTest {
     assertThat(fileHeader.getLastModifiedTime()).isEqualTo(javaToDosTime(zipParameters.getLastModifiedFileTime()));
   }
 
+  @Test
+  public void testGenerateFileHeaderWithCompressionLeveUltra() throws ZipException {
+    ZipParameters zipParameters = generateZipParameters();
+    zipParameters.setCompressionLevel(CompressionLevel.ULTRA);
+
+    FileHeader fileHeader = fileHeaderFactory.generateFileHeader(zipParameters, false, 0, InternalZipConstants.CHARSET_UTF_8);
+
+    verifyCompressionLevelGridForDeflate(CompressionLevel.ULTRA, fileHeader.getGeneralPurposeFlag()[0]);
+  }
+
   @Test
   public void testGenerateFileHeaderWithCompressionLevelMaximum() throws ZipException {
     ZipParameters zipParameters = generateZipParameters();
@@ -261,6 +271,7 @@ public class FileHeaderFactoryTest {
     fileHeader.setCompressedSize(23523L);
     fileHeader.setGeneralPurposeFlag(new byte[] {2, 28});
     fileHeader.setDataDescriptorExists(true);
+    fileHeader.setExtraFieldLength(190);
     return fileHeader;
   }
 
@@ -290,6 +301,7 @@ public class FileHeaderFactoryTest {
     verifyCrc(fileHeader);
     assertThat(fileHeader.isDataDescriptorExists()).isEqualTo(zipParameters.isWriteExtendedLocalFileHeader());
     assertThat(fileHeader.getAesExtraDataRecord() != null).isEqualTo(aesExtraDataRecordPresent);
+    assertThat(fileHeader.getExtraFieldLength()).isEqualTo(aesExtraDataRecordPresent ? InternalZipConstants.AES_EXTRA_DATA_RECORD_SIZE : 0);
   }
 
   private void verifyLocalFileHeader(LocalFileHeader localFileHeader, long lastModifiedFileTime) {
@@ -307,6 +319,7 @@ public class FileHeaderFactoryTest {
     assertThat(localFileHeader.getCompressedSize()).isEqualTo(23523L);
     assertThat(localFileHeader.getGeneralPurposeFlag()).containsExactly(2, 28);
     assertThat(localFileHeader.isDataDescriptorExists()).isTrue();
+    assertThat(localFileHeader.getExtraFieldLength()).isEqualTo(190);
   }
 
   private void verifyCompressionMethod(FileHeader fileHeader, ZipParameters zipParameters) {
@@ -343,18 +356,21 @@ public class FileHeaderFactoryTest {
 
   private void verifyCompressionLevelGridForDeflate(CompressionLevel compressionLevel,
                                                     byte firstByteOfGeneralPurposeBytes) {
-    if (compressionLevel == CompressionLevel.NORMAL) {
+    if (CompressionLevel.NORMAL.equals(compressionLevel)) {
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 1)).isFalse();
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 2)).isFalse();
-    } else if (compressionLevel == CompressionLevel.MAXIMUM) {
+    } else if (CompressionLevel.MAXIMUM.equals(compressionLevel)) {
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 1)).isTrue();
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 2)).isFalse();
-    } else if (compressionLevel == CompressionLevel.FAST) {
+    } else if (CompressionLevel.FAST.equals(compressionLevel)) {
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 1)).isFalse();
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 2)).isTrue();
-    } else if (compressionLevel == CompressionLevel.FASTEST) {
+    } else if (CompressionLevel.FASTEST.equals(compressionLevel)
+        || CompressionLevel.ULTRA.equals(compressionLevel)) {
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 1)).isTrue();
       assertThat(isBitSet(firstByteOfGeneralPurposeBytes, 2)).isTrue();
+    } else {
+      throw new RuntimeException("Invalid compression level");
     }
   }
 
